==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRGOnSegments.js <==
var group__PkgShapeDetectionRGOnSegments =
[
    [ "Least_squares_line_fit_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#afc132350c16ab42dbb24b8df12ab94a6", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a12f9ee0e53dde2ecf73590f550588a29", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a1875e3e76253b0b17df6ab02408cfd82", null ],
      [ "Region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a417575fd35df3b49eb937619f99b8791", null ],
      [ "Region_index_map", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a6f019526f3a8f482a1ec242246265ce4", null ],
      [ "Least_squares_line_fit_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#ac8a05e82d7017e7f27446460aebdd6ec", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#acff3dea88e51baa283169a25ba021480", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#aeb7a7a9a3ecd9586cbe3ba40c523850e", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#adbd37dfb5783c12ac208d042d1463a7b", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#afcdb119b11cae5a985f1b4b79ad5d34d", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a49f4eda466d2bbef3fcdf8fccda72673", null ]
    ] ],
    [ "Least_squares_line_fit_sorting", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a92f3e442b207daded1bfecce444dce31", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a8a072db31c0541c9fe8b389c3e8ef5fe", null ],
      [ "Least_squares_line_fit_sorting", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a83fdc4e9a7869429d3576e9349e2e3f0", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a7e59a8956bc5f5297e5877093225b76c", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#ac415f288a377dee8286c9a5e73806f19", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRGOnSegments.js <==
var group__PkgShapeDetectionRGOnSegments =
[
    [ "CGAL::Shape_detection::Segment_set::Least_squares_line_fit_region< GeomTraits, Item_, SegmentMap >", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#afc132350c16ab42dbb24b8df12ab94a6", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a12f9ee0e53dde2ecf73590f550588a29", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a1875e3e76253b0b17df6ab02408cfd82", null ],
      [ "Least_squares_line_fit_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#ac8a05e82d7017e7f27446460aebdd6ec", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#acff3dea88e51baa283169a25ba021480", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#aeb7a7a9a3ecd9586cbe3ba40c523850e", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#adbd37dfb5783c12ac208d042d1463a7b", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#afcdb119b11cae5a985f1b4b79ad5d34d", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__region.html#a49f4eda466d2bbef3fcdf8fccda72673", null ]
    ] ],
    [ "CGAL::Shape_detection::Segment_set::Least_squares_line_fit_sorting< GeomTraits, Item_, NeighborQuery, SegmentMap >", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a92f3e442b207daded1bfecce444dce31", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a8a072db31c0541c9fe8b389c3e8ef5fe", null ],
      [ "Least_squares_line_fit_sorting", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a83fdc4e9a7869429d3576e9349e2e3f0", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#a3d56564ff1590317a20e11e9fe0494cc", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Segment__set_1_1Least__squares__line__fit__sorting.html#ac415f288a377dee8286c9a5e73806f19", null ]
    ] ]
];
